@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import List
 
 from sym.cli.data.request_data import RequestData
 from sym.cli.errors import CliError
@@ -19,10 +20,7 @@ class SymAction(ABC):
             ValueError: if any part of request data is invalid (e.g. missing resource)
         """
 
-        if not request_data.resource:
-            raise CliError("must specify a resource.")
-
-    def get_requirements(self) -> [SymCheck]:
+    def get_requirements(self) -> List[SymCheck]:
         return []
 
     def invoke_requirements(self):
