@@ -1,4 +1,5 @@
 import os
+import sys
 from contextlib import contextmanager
 from os import X_OK, access, get_exec_path, link
 from os.path import join as join_path
@@ -9,6 +10,9 @@ from typing import Optional, Sequence, TextIO
 from portalocker import Lock
 from portalocker.constants import LOCK_EX, LOCK_NB, LOCK_SH
 
+from sym.cli.helpers.contexts import push_envs
+from sym.cli.helpers.keywords_to_options import keywords_to_options
+
 
 def read_lock(path: Path):
     return Lock(str(path), mode="r", flags=LOCK_SH | LOCK_NB)
@@ -76,3 +80,14 @@ def has_command(command: str) -> bool:
         return bool(find_command(command))
     except ValueError:
         return False
+
+
+def reset_fds():
+    for fd in [sys.stdout, sys.stderr]:
+        fd.flush()
+
+
+def execvp(client, args: Sequence[str]):
+    reset_fds()
+    with push_envs(client.get_creds()):
+        os.execvp(args[0], keywords_to_options(args))
