@@ -14,12 +14,13 @@ import click
 import requests
 from semver import VersionInfo
 
-from .config import Config
+from .config import Config, SymConfigFile
 from .contexts import push_envs
 from .os import has_command, reset_fds
 
 REQ_TIMEOUT = 3
-INSTALL_TIMEOUT = 60
+INSTALL_TIMEOUT = 90
+FAIL_LOG_PATH = "updater/fail.log"
 V0 = VersionInfo.parse("0.0.0")
 
 
@@ -40,6 +41,13 @@ class SymUpdater:
             return
         click.secho(s, err=True, **kwargs)
 
+    def _fail_log(self, s: Optional[str]):
+        if not s:
+            return
+        config_file = SymConfigFile(file_name=FAIL_LOG_PATH, uid_scope=False)
+        config_file.put(s)
+        self._log(f"A log has been written to {config_file.path}", fg="bright_black")
+
     def should_check(self) -> bool:
         return not self.is_local() and Config.check_for_update()
 
@@ -138,14 +146,16 @@ class SymUpdater:
                 timeout=INSTALL_TIMEOUT,
                 **kwargs,
             )
-        except TimeoutExpired:
+        except TimeoutExpired as e:
             self._log(
                 "Oops! This is taking a little too long, we'll try again later.",
                 fg="yellow",
             )
+            self._fail_log(e.stderr or e.stdout)
             return None
         except CalledProcessError as e:
             self._log(f"{e.returncode}: {e.stderr or e.stdout}", debug=True, fg="red")
+            self._fail_log(e.stderr or e.stdout)
             return None
 
     def _update_with_checked_command(self, command: Sequence[str], **kwargs):
@@ -181,12 +191,20 @@ class SymUpdater:
             if not res:
                 return False
 
-            return self._update_with_checked_command(
+            if not self._update_with_checked_command(
                 ["git", "pull", "origin", "master"],
                 cwd=res.stdout.strip(),
-            ) and self._update_with_checked_command(
+            ):
+                return False
+
+            if not self._update_with_checked_command(
                 ["brew", "upgrade", "-f", Config.get_dir_name()]
-            )
+            ):
+                # Make sure we never leave an orphaned install:
+                self._update_with_checked_command(["brew", "link", Config.get_dir_name()])
+                return False
+
+            return True
 
     def update_sitepackage(self) -> bool:
         pip = self.dir.parent.parent.parent / "bin" / "pip"
