@@ -5,6 +5,7 @@ from pathlib import Path
 from typing import Iterator, Tuple
 
 from ..decorators import command_require_bins, intercept_errors, run_subprocess
+from ..errors import InvalidResource
 from ..helpers.boto import get_identity
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument
@@ -26,17 +27,28 @@ class AwsProfile(SAMLClient):
     options: "GlobalOptions"
 
     @classmethod
-    def validate_resource(cls, resource: str):
+    def _read_creds_config(cls):
         config = ConfigParser(strict=False)
         config.read(AwsCredentialsPath)
+        return config
+
+    @classmethod
+    def validate_resource(cls, resource: str):
+        config = cls._read_creds_config()
         return config.has_section(resource)
 
     @cached_property
     def _section(self):
-        config = ConfigParser(strict=False)
-        config.read(AwsCredentialsPath)
+        config = self.__class__._read_creds_config()
         return config[self.resource]
 
+    def raise_if_invalid(self):
+        if self.__class__.validate_resource(self.resource):
+            return
+        raise InvalidResource(
+            self.resource, self.__class__._read_creds_config().sections()
+        )
+
     def get_creds(self):
         creds = {k.upper(): v for k, v in self._section.items() if k.startswith("aws")}
         creds["AWS_REGION"] = self._section.get("region")
