@@ -295,10 +295,10 @@ class TestWriteCreds:
         return creds_dict
 
     @pytest.fixture
-    def setup(self, capture_command, click_setup, creds_env):
+    def setup(self, capture_command, no_click_setup, creds_env):
         @contextmanager
         def _setup(create_binary=True, creds=creds_env):
-            with click_setup(set_client=create_binary):
+            with no_click_setup(set_client=create_binary):
                 with capture_command():
                     capture_command.register_output(r"env", _env_str(creds))
                     yield
