@@ -1,8 +1,10 @@
 from unittest.mock import patch
 
+import pytest
 from expects import expect, match
 
-from sym.cli.helpers.ansible import get_ansible_bucket_name
+from sym.cli.errors import InvalidResource
+from sym.cli.helpers.ansible import get_ansible_bucket_name, run_ansible
 from sym.cli.helpers.params import Profile
 from sym.cli.tests.commands.test_ansible import TEST_ACCOUNT, get_caller_identity_stub
 
@@ -32,3 +34,14 @@ class TestAnsibleHelpers:
     def test_get_ansible_bucket_name_from_profile(self, boto_stub, saml_client):
         actual = get_ansible_bucket_name(saml_client)
         expect(actual).to(match("foo"))
+
+    def test_ansible_bad_profile(self, click_context, saml_client):
+        with click_context:
+            with pytest.raises(InvalidResource):
+                run_ansible(
+                    saml_client,
+                    ("foo",),
+                    ansible_aws_profile="invalid",
+                    ansible_sym_resource=None,
+                    forks=1,
+                )
